@@ -30,6 +30,147 @@ import talib
 import talib
 from cryptotoolbox.risk_metrics import riskmetrics
 
+def strat_weekly(y, btc='BTC', tone=14,ttwo=23,p1=1.01, p2=1.05, long_expo=1., short_expo=0., rebalancing_day=5):  # On rentre le dataframe
+    weekday = y.weekday.values
+    cours = y[btc].values
+    T = np.size(weekday)
+    S = np.zeros(T)
+    for t in range(ttwo, T):
+        if weekday[t] == rebalancing_day and cours[t - ttwo] > 0:
+            if cours[t] > cours[t - tone] * p1 and cours[t] > cours[t - ttwo] * p2:
+                S[t] = long_expo
+            else:
+                S[t] = short_expo
+        else:
+            S[t] = S[t - 1]
+    return S
+
+#def strat_daily_BTC(y, btc='BTC', p1=1.1, p2=1.2, long_expo = 1., short_expo = 0.):  # On rentre le dataframe
+def strat_daily(y, btc='BTC',tone=15,ttwo=26, p1=1., p2=1.05, long_expo=1., short_expo=0., ):  # On rentre le dataframe
+    cours = y[btc].values
+    T = np.size(cours)
+    S = np.zeros(T)
+    for t in range(22, T):
+        if cours[t] > cours[t - tone] * p1 and cours[t] > cours[t - ttwo] * p2:
+            S[t] = long_expo
+        else:
+            S[t] = short_expo
+    return S
+
+def compute_alpha_signal_weekly_lo(df=None, core_tokens=['BTC', 'ETH'], extra_tokens=['AVAX'],     p1btc = 1.01, p2btc = 1.05, p1eth = 1.01, p2eth = 1.05, tone = 14,ttwo = 23, rebalancing_day=6,lo_sig_suffix='LO',compute_lo_strat=True, plot_html=False, whole_kpis=False,local_root_directory='None'):
+    all_tokens = core_tokens + extra_tokens
+    df['weekday'] = df.index.weekday
+    df['rebalance'] = df.index.weekday == rebalancing_day
+    for me_token in all_tokens:
+        df[f'return_{me_token}'] = df[f'close_{me_token}'].pct_change().fillna(0)
+    df.replace([np.inf], 0, inplace=True)
+    weekly = pd.DataFrame(index=df.index,
+                          data={'SBTC': strat_weekly(df, 'close_BTC', tone=tone, ttwo=ttwo, p1=p1btc, p2=p2btc, rebalancing_day=rebalancing_day)})
+    addw = pd.DataFrame(index=df.index,
+                        data={'S{}'.format('ETH'): strat_weekly(df, 'close_ETH',  p1=p1eth,p2=p2eth,rebalancing_day=rebalancing_day)})
+    weekly = weekly.join(addw, how='left')
+    for i in extra_tokens:
+        addw = pd.DataFrame(index=df.index, data={'S{}'.format(i): strat_weekly(df, f'close_{i}', rebalancing_day=rebalancing_day)})
+        weekly = weekly.join(addw, how='left')
+    dfsig = weekly.copy()
+    dfsig2 = dfsig.copy()
+    ######
+    df = pd.merge(df.copy(), dfsig2.copy(), how='left', right_index=True, left_index=True)
+    def curate_signals(row,under='BTC'):
+        if abs(row[f'close_{under}']) <= 1e-3:
+            return np.nan
+        else:
+            return row[f'S{ssj}']
+
+    for ssj in core_tokens + extra_tokens:
+        go_curate = lambda x: curate_signals(x, under=ssj)
+        df[f'S{ssj}'] = df.apply(go_curate, axis=1)
+
+    signal_df = df.copy()
+    signal_df = signal_df.fillna(0.)
+    signal_df['Counter'] = 0
+    for i in all_tokens:
+        if 'S{}'.format(i) in signal_df.columns:
+            signal_df['Counter'] += signal_df['S{}'.format(i)]
+
+    def expo(y, n_max=3):
+        S = np.zeros(np.size(y))
+        for i in range(np.size(y)):
+            if y[i] > n_max:
+                S[i] = 1 / y[i]
+            elif y[i] > 0:
+                S[i] = 1. / n_max
+            else:
+                S[i] = 0
+        return S
+
+    n_max = int(len(all_tokens) / 2.) + 1
+    signal_df['expo'] = expo(signal_df['Counter'].values, n_max=n_max)
+
+    for me_tok in all_tokens:
+        if not 'S{}'.format(me_tok) in signal_df.columns:
+            signal_df[f'S{me_tok}'] = 0.
+
+    for me_tok in all_tokens:
+        signal_df[f'SE{me_tok}'] = signal_df[f'S{me_tok}'] * signal_df['expo']
+
+    for i in all_tokens:
+        signal_df[f'S{lo_sig_suffix}{i}'] = signal_df[f'SE{i}'].shift(1)
+        signal_df[f'SRAW{lo_sig_suffix}{i}'] = signal_df[f'S{i}'].shift(1)
+
+
+    signal_df[f'total_expo'] = 0.
+    for me_tok in all_tokens:
+        signal_df[f'total_expo'] = signal_df[f'total_expo'] + signal_df[f'S{lo_sig_suffix}{me_tok}']
+
+    fin_df = signal_df.copy()
+    kpi_df = None
+    if compute_lo_strat:
+        def compute_return(row, tokens=[]):
+            total_return = 0.
+            for me_tok in tokens:
+                total_return = total_return + row[f'return_{me_tok}'] * row[f'S{lo_sig_suffix}{me_tok}']
+            return total_return
+
+        comp_ret = lambda x: compute_return(x, tokens=all_tokens)
+        fin_df['TR'] = fin_df.apply(comp_ret, axis=1)
+        fin_df['TR'] = fin_df['TR'].fillna(0.)
+        me_strat = 'strat'
+        fin_df[me_strat] = np.cumprod(1 + fin_df['TR'].values)
+        title = 'BTC_weekly_lo'
+        if plot_html:
+            fig = realtime_plotting_utility.plot_multiple_time_series(
+                data_df=fin_df[[me_strat]],
+                logy=True, split=False,
+                put_on_same_scale=False,
+                title=title)
+            fig.show()
+
+
+        backtest_df = fin_df[['strat']].copy()
+
+        strat_data_df = backtest_df[['strat']].copy()
+        from cryptotoolbox.analyzer import market
+
+        # strat_data_df = strat_data_df[strat_data_df.index >= '2021-02-01'].copy()
+        ma = market.MarketAnalyzer(strat_data_df, hourlyze=True)
+
+        print('computing kpis')
+        kpi_df = ma.get_kpi().T
+        kpi_df = kpi_df.dropna()
+        kpi_df = kpi_df[~np.isnan(kpi_df.sharpe)]
+        print(kpi_df.head())
+
+
+        if whole_kpis:
+            backtest_df.columns = ['strat']
+            riskmetrics.compute_plot_excel_kpis_meterics_metrics(backtest_df, title,
+                                                                 local_root_directory,
+                                                                 plot_html=True,
+                                                                 write_file=True)
+    return fin_df.copy(), kpi_df
+
+
 def combine_lo_sigs(lo_df = None, rsilo_df = None, core_tokens=None, extra_tokens=None,plot_all_strat = True):
     def filter_daily(dataframe):
         dataframe['day'] = dataframe.index.hour == 23
