@@ -458,6 +458,32 @@ def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_c
     data['reconstituted_under'] = metrics.from_ret_to_price(data['close_return'],initial_price=initial_price)
     return data, average_turn_over
 
+def reconstitute_signal_perf_out_costs(data=None, initial_price = 1. , average_execution_cost = 5e-4 , transaction_cost = True, print_turnover = True, normalization = False, recompute_return=True):
+    if normalization:
+        #data.signal = (data.signal - data.signal.mean())/data.signal.std(ddof=0)
+        data.signal = expanding_zscore(signal_np_array=data.signal.values)
+    data['turn_over'] = abs(data['signal'] - data['signal'].shift(1).fillna(0.))
+    average_turn_over = data['turn_over'].sum() / len(data)
+    if print_turnover:
+        print('average freqly turn over')
+        print(average_turn_over)
+        print('average exposure')
+        print(data['signal'].sum() / len(data))
+    if recompute_return:
+        data['close_return'] = data['close'].pct_change()
+    data['reconstituted_close'] = metrics.from_ret_to_price(data['close_return'],initial_price=initial_price)
+    data['non_adjusted_perf_return'] = data['close_return'] * data['signal']
+    global_transaction_costs = 0
+    if transaction_cost :
+        local_cost = data['turn_over'].values * average_execution_cost
+        global_transaction_costs = np.sum(local_cost)
+        data['perf_return'] = data['non_adjusted_perf_return']- data['turn_over']*average_execution_cost
+    else :
+        data['perf_return'] = data['non_adjusted_perf_return']
+    data['reconstituted_perf'] = metrics.from_ret_to_price(data['perf_return'],initial_price=initial_price)
+    data['reconstituted_under'] = metrics.from_ret_to_price(data['close_return'],initial_price=initial_price)
+    return data, average_turn_over, global_transaction_costs
+
 def reconstitute_prediction_perf(y_pred=None, y_true=None, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True, print_turnover = False):
     if not isinstance(y_pred, pd.DataFrame):
         y_pred=pd.DataFrame(y_pred)
